# FACT_data Reader
`FACTDataReader` is a Julia module designed to query and retrieve results from [`FACT Data Services`](https://git.nilu.no/fact/data). This utility module allows for efficient access to various components of FACT_data, providing an interface to query them and obtain results in the form of Julia DataFrames.

---
## Use

To use `FACTDataReader`, ensure that you have Julia installed along with the required dependencies: `DataFrames`, `MySQL`, `Tables`, `LibGEOS`, `HTTP`, and `JSON`. The module includes various utility files and specific data access files for different domains such as geography, roads, jobs, population, air traffic, etc.

Here's a quick start guide:

1. **Import the Module**:
```julia
using FACTDataReader
```
2.  **Query FACT_data Components**:

You can query different components of FACT_data. For example:
```julia
geo_objects = get_geo_objects(...)
travel_data_eu = get_travel_data_eu(...)
annual_jobs = get_annual_jobs(...)
```
Replace ... with the necessary parameters for each function.

---
## Specifications
The APIs are at https://fact.pages.nilu.no/utils/FACTDataReader

`FACTDataReader` includes the following functionalities to access the different [`FACT Data Services`](https://git.nilu.no/fact/data):
1. Geographical Data: Retrieve geographical objects.
2. Travel Data (EU and NA): Obtain travel-related data for Europe and North America.
3. Annual Jobs Data: Access data related to jobs on an annual basis.
4. Population Data: Query annual population statistics.
5. Air Traffic Data: Get information on airports and their traffic.
6. Elevation Data: Access elevation-related data through a web service.
7. Rail Stations and Lines: Retrieve data about rail stations and lines.
8. Ports Tonnage: Get information on ports and their tonnage.
9. Power Stations and Lines: Access data on power stations and power lines.
10. Land Use Data: Obtain land use data.
11. Geology and Minerals: Query geological data and mineral resources.
12. Building footprint and height: Obtain estimation on buildings footprints from ML on multiple remote sensing sources.

---
## Notes
- The module is structured to interact with both databases and web services, depending on the type of data being accessed.
- Some functionalities are commented out in the current version and might be included in future releases.
- This module is designed for use with Julia and requires an understanding of Julia DataFrames for effective utilization.
- Tests are available under the test directory, providing real-world use cases in both the US and EU.


For more detailed information on each function and its parameters, please refer to the individual function documentation within the module.

---
### Authors
Riccardo Boero - ribo@nilu.no

### License
